# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/areas_of_interest_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/areas_of_interest_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0fsai_grpc_api/protos/areas_of_interest_api.proto\x1a fsai_grpc_api/protos/utils.proto\"L\n\x0e\x41reaOfInterest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x03 \x01(\x0b\x32\x08.GeoBbox\"N\n!FindOrCreateAreaOfInterestRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"q\n\"FindOrCreateAreaOfInterestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"O\n\"UpdateAreaOfInterestGeoBboxRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"r\n#UpdateAreaOfInterestGeoBboxResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"L\n\x1f\x44\x65leteAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"D\n DeleteAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType2\xc6\x02\n\x12\x41reasOfInterestApi\x12\x65\n\x1a\x46indOrCreateAreaOfInterest\x12\".FindOrCreateAreaOfInterestRequest\x1a#.FindOrCreateAreaOfInterestResponse\x12h\n\x1bUpdateAreaOfInterestGeoBbox\x12#.UpdateAreaOfInterestGeoBboxRequest\x1a$.UpdateAreaOfInterestGeoBboxResponse\x12_\n\x18\x44\x65leteAreaOfInterestById\x12 .DeleteAreaOfInterestByIdRequest\x1a!.DeleteAreaOfInterestByIdResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_AREAOFINTEREST = _descriptor.Descriptor(
  name='AreaOfInterest',
  full_name='AreaOfInterest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='AreaOfInterest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='AreaOfInterest.mission_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_bbox', full_name='AreaOfInterest.geo_bbox', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=162,
)


_FINDORCREATEAREAOFINTERESTREQUEST = _descriptor.Descriptor(
  name='FindOrCreateAreaOfInterestRequest',
  full_name='FindOrCreateAreaOfInterestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='FindOrCreateAreaOfInterestRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=242,
)


_FINDORCREATEAREAOFINTERESTRESPONSE = _descriptor.Descriptor(
  name='FindOrCreateAreaOfInterestResponse',
  full_name='FindOrCreateAreaOfInterestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateAreaOfInterestResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='FindOrCreateAreaOfInterestResponse.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=357,
)


_UPDATEAREAOFINTERESTGEOBBOXREQUEST = _descriptor.Descriptor(
  name='UpdateAreaOfInterestGeoBboxRequest',
  full_name='UpdateAreaOfInterestGeoBboxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='UpdateAreaOfInterestGeoBboxRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=359,
  serialized_end=438,
)


_UPDATEAREAOFINTERESTGEOBBOXRESPONSE = _descriptor.Descriptor(
  name='UpdateAreaOfInterestGeoBboxResponse',
  full_name='UpdateAreaOfInterestGeoBboxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateAreaOfInterestGeoBboxResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='UpdateAreaOfInterestGeoBboxResponse.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=554,
)


_DELETEAREAOFINTERESTBYIDREQUEST = _descriptor.Descriptor(
  name='DeleteAreaOfInterestByIdRequest',
  full_name='DeleteAreaOfInterestByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='DeleteAreaOfInterestByIdRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=632,
)


_DELETEAREAOFINTERESTBYIDRESPONSE = _descriptor.Descriptor(
  name='DeleteAreaOfInterestByIdResponse',
  full_name='DeleteAreaOfInterestByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteAreaOfInterestByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=634,
  serialized_end=702,
)

_AREAOFINTEREST.fields_by_name['geo_bbox'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOBBOX
_FINDORCREATEAREAOFINTERESTREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_FINDORCREATEAREAOFINTERESTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEAREAOFINTERESTRESPONSE.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_UPDATEAREAOFINTERESTGEOBBOXREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_UPDATEAREAOFINTERESTGEOBBOXRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEAREAOFINTERESTGEOBBOXRESPONSE.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_DELETEAREAOFINTERESTBYIDREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_DELETEAREAOFINTERESTBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
DESCRIPTOR.message_types_by_name['AreaOfInterest'] = _AREAOFINTEREST
DESCRIPTOR.message_types_by_name['FindOrCreateAreaOfInterestRequest'] = _FINDORCREATEAREAOFINTERESTREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateAreaOfInterestResponse'] = _FINDORCREATEAREAOFINTERESTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAreaOfInterestGeoBboxRequest'] = _UPDATEAREAOFINTERESTGEOBBOXREQUEST
DESCRIPTOR.message_types_by_name['UpdateAreaOfInterestGeoBboxResponse'] = _UPDATEAREAOFINTERESTGEOBBOXRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAreaOfInterestByIdRequest'] = _DELETEAREAOFINTERESTBYIDREQUEST
DESCRIPTOR.message_types_by_name['DeleteAreaOfInterestByIdResponse'] = _DELETEAREAOFINTERESTBYIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AreaOfInterest = _reflection.GeneratedProtocolMessageType('AreaOfInterest', (_message.Message,), {
  'DESCRIPTOR' : _AREAOFINTEREST,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:AreaOfInterest)
  })
_sym_db.RegisterMessage(AreaOfInterest)

FindOrCreateAreaOfInterestRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateAreaOfInterestRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEAREAOFINTERESTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateAreaOfInterestRequest)
  })
_sym_db.RegisterMessage(FindOrCreateAreaOfInterestRequest)

FindOrCreateAreaOfInterestResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateAreaOfInterestResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEAREAOFINTERESTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateAreaOfInterestResponse)
  })
_sym_db.RegisterMessage(FindOrCreateAreaOfInterestResponse)

UpdateAreaOfInterestGeoBboxRequest = _reflection.GeneratedProtocolMessageType('UpdateAreaOfInterestGeoBboxRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAREAOFINTERESTGEOBBOXREQUEST,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateAreaOfInterestGeoBboxRequest)
  })
_sym_db.RegisterMessage(UpdateAreaOfInterestGeoBboxRequest)

UpdateAreaOfInterestGeoBboxResponse = _reflection.GeneratedProtocolMessageType('UpdateAreaOfInterestGeoBboxResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAREAOFINTERESTGEOBBOXRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateAreaOfInterestGeoBboxResponse)
  })
_sym_db.RegisterMessage(UpdateAreaOfInterestGeoBboxResponse)

DeleteAreaOfInterestByIdRequest = _reflection.GeneratedProtocolMessageType('DeleteAreaOfInterestByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAREAOFINTERESTBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteAreaOfInterestByIdRequest)
  })
_sym_db.RegisterMessage(DeleteAreaOfInterestByIdRequest)

DeleteAreaOfInterestByIdResponse = _reflection.GeneratedProtocolMessageType('DeleteAreaOfInterestByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAREAOFINTERESTBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteAreaOfInterestByIdResponse)
  })
_sym_db.RegisterMessage(DeleteAreaOfInterestByIdResponse)



_AREASOFINTERESTAPI = _descriptor.ServiceDescriptor(
  name='AreasOfInterestApi',
  full_name='AreasOfInterestApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=705,
  serialized_end=1031,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateAreaOfInterest',
    full_name='AreasOfInterestApi.FindOrCreateAreaOfInterest',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATEAREAOFINTERESTREQUEST,
    output_type=_FINDORCREATEAREAOFINTERESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAreaOfInterestGeoBbox',
    full_name='AreasOfInterestApi.UpdateAreaOfInterestGeoBbox',
    index=1,
    containing_service=None,
    input_type=_UPDATEAREAOFINTERESTGEOBBOXREQUEST,
    output_type=_UPDATEAREAOFINTERESTGEOBBOXRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAreaOfInterestById',
    full_name='AreasOfInterestApi.DeleteAreaOfInterestById',
    index=2,
    containing_service=None,
    input_type=_DELETEAREAOFINTERESTBYIDREQUEST,
    output_type=_DELETEAREAOFINTERESTBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AREASOFINTERESTAPI)

DESCRIPTOR.services_by_name['AreasOfInterestApi'] = _AREASOFINTERESTAPI

# @@protoc_insertion_point(module_scope)
