# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import areas_of_interest_api_pb2 as fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2


class AreasOfInterestApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FindOrCreateAreaOfInterest = channel.unary_unary(
                '/AreasOfInterestApi/FindOrCreateAreaOfInterest',
                request_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.FromString,
                )
        self.UpdateAreaOfInterestGeoBbox = channel.unary_unary(
                '/AreasOfInterestApi/UpdateAreaOfInterestGeoBbox',
                request_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxResponse.FromString,
                )
        self.DeleteAreaOfInterestById = channel.unary_unary(
                '/AreasOfInterestApi/DeleteAreaOfInterestById',
                request_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.FromString,
                )


class AreasOfInterestApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FindOrCreateAreaOfInterest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAreaOfInterestGeoBbox(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAreaOfInterestById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AreasOfInterestApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FindOrCreateAreaOfInterest': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateAreaOfInterest,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.SerializeToString,
            ),
            'UpdateAreaOfInterestGeoBbox': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAreaOfInterestGeoBbox,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxResponse.SerializeToString,
            ),
            'DeleteAreaOfInterestById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAreaOfInterestById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'AreasOfInterestApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AreasOfInterestApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FindOrCreateAreaOfInterest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreasOfInterestApi/FindOrCreateAreaOfInterest',
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAreaOfInterestGeoBbox(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreasOfInterestApi/UpdateAreaOfInterestGeoBbox',
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAreaOfInterestById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreasOfInterestApi/DeleteAreaOfInterestById',
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
